@@ -511,12 +511,8 @@ C
 C7000 FORMAT(47H0ERROR , THE OPTIMALITY	CONDITIONS ARE VIOLATED,
 C    *	     10X,6HEDGE	(,I3,1H,,I3,1H),5X,F15.4)
 C
-C     THE FOLLOWING FORMAT "7000" CORRECTS THE ORIGINAL FORMAT
-C     ABOVE TO RESTRICT THE OUTPUT TO LESS THAN 80 CHARACTERS
-C     PER LINE.
-C
- 7000 FORMAT(47H0ERROR , THE OPTIMALITY CONDITIONS ARE VIOLATED
-     *   /1H ,8X,6HEDGE (,I3,1H,,I3,1H),5X,F15.4)
+C     THE FOLLOWING RPRINT ROUTINE CORRECTS THE ORIGINAL FORMAT
+C     ABOVE, AND REMOVES LEGACY HOLLERITH CONSTANTS
 C
       END
 C
